--
--  Copyright 2013 Anyware Services
--
--  Licensed under the Apache License, Version 2.0 (the "License");
--  you may not use this file except in compliance with the License.
--  You may obtain a copy of the License at
--
--      http://www.apache.org/licenses/LICENSE-2.0
--
--  Unless required by applicable law or agreed to in writing, software
--  distributed under the License is distributed on an "AS IS" BASIS,
--  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
--  See the License for the specific language governing permissions and
--  limitations under the License.
--
CREATE TABLE Cache_RA_HTTPServer (
  Unique_Id VARCHAR(255) NOT NULL,
  Site VARCHAR(255) NOT NULL,
  Request_Date TIMESTAMP NOT NULL,
  Method VARCHAR(255) NOT NULL,
  Path_Hash VARCHAR(255) NOT NULL,
  Path CLOB NOT NULL,
  Query_String CLOB NOT NULL,
  Ori_Status_Code CHAR(3) NOT NULL,
  Ret_Status_Code CHAR(3) NOT NULL,
  Cache_Hit NUMBER(1) NOT NULL,
  Created_At TIMESTAMP NOT NULL,
  Processed NUMBER(1) DEFAULT 0 NOT NULL,
  PRIMARY KEY (Unique_Id)
);


CREATE TABLE Cache_RA_Front (
  Unique_Id VARCHAR(255) NOT NULL,
  Internal_Uuid VARCHAR(255) NOT NULL,
  Site VARCHAR(255) NOT NULL,
  Ametys_Path_Hash VARCHAR(255) NOT NULL,
  Ametys_Path CLOB NOT NULL,
  Cacheable NUMBER(1) NOT NULL,
  Cache_Hit_1 NUMBER(1) NOT NULL,
  Cache_Hit_2 NUMBER(1) NOT NULL,
  Created_At TIMESTAMP NOT NULL,
  Processed NUMBER(1) DEFAULT 0 NOT NULL
);

CREATE TABLE Cache_RA_Back (
  Internal_Uuid VARCHAR(255) NOT NULL,
  Page_Id VARCHAR(255) NOT NULL,
  Page_Path_Hash VARCHAR(255) NOT NULL,
  Page_Path CLOB NOT NULL,
  Rendering_Context VARCHAR(255) NOT NULL,
  Workspace_JCR VARCHAR(255) NOT NULL,
  Cacheable NUMBER(1) NOT NULL,
  Created_At TIMESTAMP NOT NULL,
  Processed NUMBER(1) DEFAULT 0 NOT NULL
);

CREATE TABLE Cache_RA_Back_Page_Element (
  Internal_Uuid VARCHAR(255) NOT NULL,
  Page_Element_Id VARCHAR(255) NOT NULL,
  Page_Element_Type VARCHAR(255) NOT NULL,
  Page_Id VARCHAR(255) NOT NULL,
  Rendering_Context VARCHAR(255) NOT NULL,
  Workspace_JCR VARCHAR(255) NOT NULL,
  Cacheable NUMBER(1) NOT NULL,
  Cache_Hit NUMBER(1) NOT NULL,
  Created_At TIMESTAMP NOT NULL,
  Processed NUMBER(1) DEFAULT 0 NOT NULL
);

CREATE TABLE Cache_Stats_Front (
  Server_Site VARCHAR(255) DEFAULT '-' NOT NULL,
  Server_Path_Hash VARCHAR(255) DEFAULT '-' NOT NULL,
  Server_Path CLOB,
  Server_Hits INT DEFAULT 0 NOT NULL,
  Server_Cache_Hits INT DEFAULT 0 NOT NULL,
  Front_Site VARCHAR(255) DEFAULT '-' NOT NULL,
  Front_Path_Hash VARCHAR(255) DEFAULT '-' NOT NULL,
  Front_Path CLOB,
  Front_Cacheable NUMBER(1) DEFAULT 0 NOT NULL,
  Front_Hits INT DEFAULT 0 NOT NULL,
  Front_Cache_Hits_1 INT DEFAULT 0 NOT NULL,
  Front_Cache_Hits_2 INT DEFAULT 0 NOT NULL,
  Created_At TIMESTAMP NOT NULL,
  Updated_At TIMESTAMP NOT NULL,
  UNIQUE (Server_Site, Server_Path_Hash, Front_Site, Front_Path_Hash)
);

CREATE TABLE Cache_Stats_Back (
  Page_Id VARCHAR(255) NOT NULL,
  Page_Path_Hash VARCHAR(255) NOT NULL,
  Page_Path CLOB NOT NULL,
  Rendering_Context VARCHAR(255) NOT NULL,
  Workspace_JCR VARCHAR(255) NOT NULL,
  Cacheable NUMBER(1) NOT NULL,
  Hits INT NOT NULL,
  Created_At TIMESTAMP NOT NULL,
  Updated_At TIMESTAMP NOT NULL,
  PRIMARY KEY (Page_Id, Rendering_Context, Workspace_JCR)
);

CREATE TABLE Cache_Stats_Back_Page_Element (
  Page_Element_Id VARCHAR(255) NOT NULL,
  Page_Id VARCHAR(255) NOT NULL,
  Rendering_Context VARCHAR(255) NOT NULL,
  Workspace_JCR VARCHAR(255) NOT NULL,
  Cacheable NUMBER(1) NOT NULL,
  Hits INT NOT NULL,
  Cache_Hits INT NOT NULL,
  Created_At TIMESTAMP NOT NULL,
  Updated_At TIMESTAMP NOT NULL,
  PRIMARY KEY (Page_Element_Id, Page_Id, Rendering_Context, Workspace_JCR)
);
